@@ -12,7 +12,7 @@ if __name__ == '__main__':
     parser.add_argument('-o', dest='output', default='xtas_config.py')
     args = parser.parse_args()
 
-    with open(join(dirname(__file__), '..', 'config.py')) as default:
+    with open(join(dirname(__file__), '..', '_defaultconfig.py')) as default:
         # XXX in Python 3, we can make this safer by opening with 'x'
         with open(args.output, 'w') as out:
             copyfileobj(default, out)
