@@ -4,6 +4,7 @@ from __future__ import absolute_import
 
 from datetime import datetime
 
+from chardet import detect as chardetect
 from elasticsearch import Elasticsearch
 
 from ..core import app, _config
@@ -17,7 +18,7 @@ _ES_DOC_FIELDS = ('index', 'type', 'id', 'field')
 
 
 def es_document(idx, typ, id, field):
-    """Returns a handle on a document living in the ES store.
+    """Returns a handle on a field in a document living in the ES store.
 
     This does not fetch the document, or even check that it exists.
     """
@@ -33,14 +34,27 @@ def fetch(doc):
     ----------
     doc : {dict, string}
         A dictionary representing a handle returned by es_document, or a plain
-        string.
+        string. A Unicode string (Python 2 unicode, Python 3 str) will be
+        returned as-is. A byte string (Python 2 str, Python 3 bytes) will be
+        run through chardet to guess the encoding, then decoded with
+        errors="replace".
+
+    Returns
+    -------
+    content : string
+        Document contents.
     """
     if isinstance(doc, dict) and set(doc.keys()) == set(_ES_DOC_FIELDS):
         idx, typ, id, field = [doc[k] for k in _ES_DOC_FIELDS]
         return _es().get_source(index=idx, doc_type=typ, id=id)[field]
-    else:
-        # Assume simple string
+    elif isinstance(doc, unicode):
         return doc
+    elif isinstance(doc, str):
+        enc = chardetect(doc)['encoding']
+        return doc.decode(enc, errors="replace")
+    else:
+        raise TypeError("fetch expected es_document or string, got %s"
+                        % type(doc))
 
 
 @app.task
